Advanced Usage Example
=======================

This example demonstrates advanced features including nested objects and lists.

.. literalinclude:: ../../../examples/advanced_usage.py
   :language: python
   :linenos:

